//
//  igViewController.m
//  ChartCustomDataAxisLabels
//
//  Created by Torrey Betts on 04/10/13.
//  Copyright (c) 2013 Infragistics. All rights reserved.
//

#import "igViewController.h"
#import <IGChart/IGChart.h>

@interface GraphObject : NSObject
@property (nonatomic,retain) NSString *territory;
@property (nonatomic, assign) double cost;
@end

@implementation GraphObject
@synthesize cost, territory;
@end

@interface igViewController () <IGChartViewDelegate>
{
    IGChartView *_chart;
    NSMutableArray *_data;
    IGCategorySeriesDataSourceHelper *_source;
}

@end

@implementation igViewController

- (void)viewDidLoad
{
    [super viewDidLoad];

    _data = [[NSMutableArray alloc] init];
    [self generateData];

    _source = [[IGCategorySeriesDataSourceHelper alloc] init];
    _source.data = _data;
    _source.valuePath = @"cost";
    _source.labelPath = @"territory";

    _chart = [[IGChartView alloc] initWithFrame:CGRectInset(self.view.frame, 30.0, 30.0)];
    [_chart setAutoresizingMask:UIViewAutoresizingFlexibleWidth|UIViewAutoresizingFlexibleHeight];
    _chart.theme = [IGChartGradientThemes IGThemeDark];
    _chart.delegate = self;
    [self.view addSubview:_chart];

    [_chart addSeriesForType:[IGColumnSeries class] usingKey:@"series" withDataSource:_source firstAxisKey:@"xAxis" secondAxisKey:@"yAxis"];
}

-(void)generateData
{
    NSArray *territories = [NSArray arrayWithObjects:@"Canada", @"Finland", @"Holland", @"Japan", @"USA", nil];

    for (int i = 0; i < 5; i++)
    {
        GraphObject *graphObject = [[GraphObject alloc] init];
        graphObject.territory = [territories objectAtIndex:i];
        graphObject.cost = arc4random() % 100000;
        [_data addObject:graphObject];
    }
}

- (NSString *)chartView:(IGChartView *)chartView labelForAxis:(IGAxis *)axis withItem:(NSObject *)item
{
    if([axis.key isEqualToString:@"xAxis"])
        return ((IGCategoryPoint *)item).label;
    else if ([axis.key isEqualToString:@"yAxis"])
    {
        NSNumberFormatter *formatter = [[NSNumberFormatter alloc] init];
        [formatter setNumberStyle:NSNumberFormatterCurrencyStyle];
        return [formatter stringFromNumber:(NSNumber *)item];
    }

    return nil;
}

@end